One of three test datasets that can be used to explore package functionality.

evs_src_01

Format

evs_src_01

A data.table objects prefixed as 'evs_src_' with the following structure:

join_key

An integer key to be used for joining datasets

date.start

A date column representing the start of an event

date.end

A date column representing the end of an event

src

A character column representing the source of the event

X_001, X_002, ...

Numeric columns representing attributes of the events, with random values between 0 and 1

Synthesized by the package author.