One of three test datasets that can be used to explore package functionality.
evs_src_03evs_src_03A data.table objects prefixed as 'evs_src_' with the following structure:
An integer key to be used for joining datasets
A date column representing the start of an event
A date column representing the end of an event
A character column representing the source of the event
Numeric columns representing attributes of the events, with random values between 0 and 1
Synthesized by the package author.